"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useGroups = exports.useGroup = exports.useForm = exports.useFieldValues = exports.useFieldValue = exports.useFieldErrors = exports.useFieldArray = exports.useField = void 0;
var _store = require("./store");
var _lodash = _interopRequireDefault(require("lodash.isequal"));
var _react = require("react");
var _group = require("./components/extra/group");
var _lodash2 = _interopRequireDefault(require("lodash.get"));
var _helpers = require("./helpers");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }
function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }
function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }
var selector = function selector(state) {
  return state;
};
var compareForm = function compareForm(oldState, newState) {
  return (0, _lodash["default"])(oldState.form, newState.form);
};
var compareField = function compareField(ids) {
  return function (oldState, newState) {
    var oldField = oldState.fields.filter(function (item) {
      return ids.indexOf(item.id) > -1;
    });
    var newField = newState.fields.filter(function (item) {
      return ids.indexOf(item.id) > -1;
    });
    return (0, _lodash["default"])(oldField, newField);
  };
};
var compareGroup = function compareGroup(name) {
  return function (oldState, newState) {
    var oldGroup = oldState.groups.find(function (item) {
      return item.name === name;
    });
    var newGroup = newState.groups.find(function (item) {
      return item.name === name;
    });
    return (0, _lodash["default"])(oldGroup, newGroup);
  };
};
var compareGroups = function compareGroups() {
  return function (oldState, newState) {
    return (0, _helpers.isArrayEqual)(oldState.groups, newState.groups);
  };
};
var compareFieldValue = function compareFieldValue(id) {
  return function (oldState, newState) {
    var oldField = oldState.fields.find(function (item) {
      return item.id === id;
    });
    var newField = newState.fields.find(function (item) {
      return item.id === id;
    });
    return (oldField === null || oldField === void 0 ? void 0 : oldField.value) === (newField === null || newField === void 0 ? void 0 : newField.value);
  };
};
var compareFieldError = function compareFieldError(id) {
  return function (oldState, newState) {
    var _oldField$errors, _newField$errors;
    var oldField = oldState.fields.find(function (item) {
      return item.id === id;
    });
    var newField = newState.fields.find(function (item) {
      return item.id === id;
    });
    return (oldField === null || oldField === void 0 ? void 0 : (_oldField$errors = oldField.errors) === null || _oldField$errors === void 0 ? void 0 : _oldField$errors.length) === (newField === null || newField === void 0 ? void 0 : (_newField$errors = newField.errors) === null || _newField$errors === void 0 ? void 0 : _newField$errors.length);
  };
};
var compareDynamicValues = function compareDynamicValues(path) {
  return function (oldState, newState) {
    var oldValue = (0, _lodash2["default"])(oldState.dynamicValues, path);
    var newValue = (0, _lodash2["default"])(newState.dynamicValues, path);
    return (0, _helpers.isArrayEqual)(oldValue, newValue);
  };
};
var useForm = function useForm() {
  var state = (0, _store.useFormStore)(function (state) {
    return state;
  }, compareForm);
  return state.formApi;
};
exports.useForm = useForm;
var useField = function useField(fieldId) {
  var props = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var autoCreate = props.autoCreate,
    disabled = props.disabled,
    dependsOn = props.dependsOn;
  var state = (0, _store.useFormStore)(selector, compareField([fieldId].concat(_toConsumableArray(dependsOn || []))));
  var group = undefined;
  try {
    group = (0, _group.useGroupStore)();
    // eslint-disable-next-line no-empty
  } catch (e) {}
  var formApi = state.formApi;
  var fieldApi = formApi.getField(fieldId, typeof autoCreate === 'undefined' ? true : autoCreate);
  (0, _react.useEffect)(function () {
    fieldApi.setDisabled(!!disabled);
  }, [disabled]);
  (0, _react.useEffect)(function () {
    fieldApi.setGroup(group ? group.name : null);
  }, [group]);
  (0, _react.useEffect)(function () {
    return function () {
      fieldApi.remove();
    };
  }, [fieldId]);
  return [fieldApi.getValue(), fieldApi.setValue, fieldApi, formApi];
};
exports.useField = useField;
var useGroup = function useGroup(groupName) {
  var props = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var defaultActive = props.defaultActive,
    autoCreate = props.autoCreate;
  var state = (0, _store.useFormStore)(selector, compareGroup(groupName));
  var formApi = state.formApi;
  var groupsApi = formApi.groupsApi;
  var groupApi = formApi.groupsApi.getGroup(groupName, typeof autoCreate === 'undefined' ? true : autoCreate, {
    isActive: !!defaultActive
  });
  (0, _react.useEffect)(function () {
    return function () {
      groupApi.remove();
    };
  }, []);
  return [groupApi, groupsApi, formApi];
};
exports.useGroup = useGroup;
var useGroups = function useGroups() {
  var state = (0, _store.useFormStore)(selector, compareGroups());
  return [state.groups, state.formApi.groupsApi, state.formApi];
};
exports.useGroups = useGroups;
var useFieldValues = function useFieldValues(fieldIds) {
  var state = (0, _store.useFormStore)(selector, compareField(fieldIds));
  return fieldIds.map(function (fieldId) {
    var fieldApi = state.formApi.getField(fieldId, false);
    return fieldApi ? fieldApi.getValue() : undefined;
  });
};
exports.useFieldValues = useFieldValues;
var useFieldValue = function useFieldValue(fieldId) {
  var state = (0, _store.useFormStore)(selector, compareFieldValue(fieldId));
  var fieldApi = state.formApi.getField(fieldId, false);
  return fieldApi ? [fieldApi.getValue(), fieldApi.getInputClassName()] : [undefined, undefined];
};
exports.useFieldValue = useFieldValue;
var useFieldErrors = function useFieldErrors(fieldId) {
  var state = (0, _store.useFormStore)(selector, compareFieldError(fieldId));
  var fieldApi = state.formApi.getField(fieldId, false);
  return fieldApi ? [fieldApi.getErrors(), fieldApi.getErrorClassName()] : [undefined, undefined];
};
exports.useFieldErrors = useFieldErrors;
var useFieldArray = function useFieldArray(fieldArrayId) {
  var state = (0, _store.useFormStore)(function (state) {
    return state;
  }, compareDynamicValues(fieldArrayId));
  var formApi = state.formApi;
  var fieldArrayApi = formApi.getFieldArray(fieldArrayId);
  return [fieldArrayApi.getItems(), fieldArrayApi, formApi];
};
exports.useFieldArray = useFieldArray;