"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useFormStore = exports.createFormStore = exports.FormStoreProvider = void 0;
var _zustand = require("zustand");
var _context = _interopRequireDefault(require("zustand/context"));
var _formProvider = require("./components/form-provider");
var _lodash = _interopRequireDefault(require("lodash.get"));
var _group = require("./apis/group");
var _form = require("./apis/form");
var _field = require("./apis/field");
var _fieldArray = require("./apis/field-array");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }
function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }
function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }
var _createContext = (0, _context["default"])(),
  FormStoreProvider = _createContext.Provider,
  useFormStore = _createContext.useStore;
exports.useFormStore = useFormStore;
exports.FormStoreProvider = FormStoreProvider;
var createFormStore = function createFormStore() {
  return (0, _zustand.create)(function (set, get) {
    var getField = function getField(fieldId) {
      var autoCreate = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
      var field = get().fields.find(function (item) {
        return item.id === fieldId;
      });
      if (!field && autoCreate) {
        field = {
          id: fieldId,
          isValidating: false,
          isDisabled: false,
          isTouched: false,
          isValid: false,
          group: null,
          value: (0, _lodash["default"])(get().dynamicValues, fieldId),
          errors: []
        };
        set({
          fields: [].concat(_toConsumableArray(get().fields), [field])
        });
      }
      return field ? (0, _field.fieldApiPure)(set, get, field) : undefined;
    };
    var getGroup = function getGroup(groupName) {
      var autoCreate = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
      var data = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
      var group = get().groups.find(function (item) {
        return item.name === groupName;
      });
      if (!group && autoCreate) {
        group = _objectSpread({
          name: groupName,
          isValidating: false,
          isDisabled: false,
          isTouched: false,
          isActive: false,
          isValid: false
        }, data);
        set({
          groups: [].concat(_toConsumableArray(get().groups), [group])
        });
      }
      return group ? (0, _group.groupApiPure)(set, get, group) : undefined;
    };
    var getFieldArray = function getFieldArray(fieldArrayId) {
      return (0, _fieldArray.fieldArrayApiPure)(set, get, fieldArrayId);
    };
    var formApi = (0, _form.formApiPure)(set, get, getField, getGroup, getFieldArray);
    return {
      form: {
        defaultValues: {},
        isStripUnknown: false,
        isValidating: false,
        isTouched: false,
        isValid: true,
        isChanged: false,
        formRef: null,
        validation: {},
        classes: _formProvider.defaultClasses
      },
      dynamicValues: {},
      fields: [],
      groups: [],
      formApi: formApi
    };
  });
};
exports.createFormStore = createFormStore;